import unittest
from qbc_qrcode import *


class MyTestCase(unittest.TestCase):
    TEST_LONG_DATA = "word文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果" \
                       "word文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果" \
                       "word文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果" \
                       "word文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果" \
                       "word文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果" \
                       "word文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果" \
                       "word文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果" \
                       "word文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果" \
                       "word文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果" \
                       "word文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果" \
                       "word文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果" \
                       "word文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果Word给用户提供了用于创建专业而优雅的文档工具，帮助用户节省时间，并得到优雅美观的结果"

    def test_make(self):
        self.assertEqual(make('I love Python', '二维码.jpg'), '二维码.jpg')
        self.assertIsNotNone(make('I love Python'))

    def test_make_typeError(self):
        with self.assertRaisesRegex(ParameterTypeError, "^参数类型错误 : 调用make方法时，'data'参数类型错误。$"):
            make(123, '二维码.jpg')
        with self.assertRaisesRegex(ParameterTypeError, "^参数类型错误 : 调用make方法时，'filename'参数类型错误。$"):
            make("I love Python", 123)

        with self.assertRaisesRegex(ParameterTypeError, "^参数类型错误 : 调用make方法时，'data'、'filename'参数类型错误。$"):
            make(123, 123)

    def test_make_valueError(self):
        with self.assertRaisesRegex(ParameterValueError, "^参数数值错误 : 调用make方法时，'data'参数不在允许范围内。$"):
            make(MyTestCase.TEST_LONG_DATA, '1.jpg')

        with self.assertRaisesRegex(ParameterValueError, "^参数数值错误 : 调用make方法时，'filename'参数不在允许范围内。$"):
            make("I love Python", '1.wav')

        with self.assertRaisesRegex(ParameterValueError, "^参数数值错误 : 调用make方法时，'data'、'filename'参数不在允许范围内。$"):
           make(MyTestCase.TEST_LONG_DATA, '1.wav')


if __name__ == '__main__':
    unittest.main()



from distutils.core import setup

setup(
    name='qbc_qrcode',
    version='1.0.4',
    description='generate a qrcode',
    long_description='generate a qrcode according input text',
    author='charlesmeng',
    author_email='charlesmeng@shinelab.cn',
    keywords=['pip3', 'qrcode', 'python3', 'python'],
    url='https://www.shinelab.cn/',
    packages=['qbc_qrcode'],
    package_data={'qbc_qrcode': ['*.py']},
    license='MIT',
    install_requires=[
        'qrcode',
        'ybc_exception'
    ],
)



from ybc_exception import *
import qrcode
import time


@exception_handler('qbc_qrcode')
@params_check([
    ParamCheckEntry('data', str, is_length_in_range, Range(1, 2000)),
    ParamCheckEntry('filename', str, is_correct_file_format, {'jpg', 'png'})
])
def make(data='', filename=''):
    """
    功能：根据data生成一张二维码图片。

    参数：data：二维码的内容，必填，长度小于等于 600
         filename：生成的图片名称，选填，默认为"当前时间戳_qrcode.jpg"

    返回：图片名称
    """
    if not filename:
        filename = str(int(time.time())) + '_qrcode.jpg'
    file = qrcode.make(data)
    file.save(filename)
    return filename


if __name__ == '__main__':
    file = make('结果')
